<?php  if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Templates extends Controller {

    function __construct() {
            parent::Controller();
            $module_name = "config";
            $this->load->model($this->config->item('smp_model'));
    }

    //---------------------------------------------------------------

    //<editor-fold desc="FUNCTION DESCRIPTION: SHOW THE TEMPLATES LIST PAGE">
    /*
     * Function: index
     * Description: Shows the templates list page
     * ##############################################################
     * Written: 10/08/2010
     * Author: Deep Arora
     * --------------------------------------------------------------
     * Update Log:
     * --------------------------------------------------------------
     * ##############################################################
     * @access public
     * @return void
     */
    //</editor-fold>
    function index($offset = '')
    {
        //<editor-fold desc="CHECK USER PERMISSION">
        smp_check_permission($this->config->item('perm_view'));
        //</editor-fold>

        //<editor-fold desc="SET PAGE META">
        $page_button_set = array(
            'Add New'    =>  'templates/record',
            'View All'    =>  'templates'
        );
        smp_set_page_meta('config', 'templates', $page_button_set);
        //</editor-fold>

        //<editor-fold desc="CREATE SEARCH FORM">
        $search_form_fields = array(
            array(
                'field'    =>  'template_title',
                'label'    =>  'Title',
                'type'     =>  'text',
                'class'    =>  '',
                'value'    =>  ''
            )
        );
        smp_create_form($search_form_fields, $this->config->item('form_template_search'), 'form_search');
        //</editor-fold>

        //<editor-fold desc="FETCHING DATA">
        $where_additional = smp_form_where_clause($_POST, $this->config->item('tbl_templates'));
        $total_records = smp_count($this->config->item('tbl_templates'), $where_additional);
        $result_set['templates'] = $this->Smp_model->get_records($this->config->item('tbl_templates'), $where_additional, $offset, $this->config->item('records_per_page'));
        $pagination = smp_set_pagination($this->config->item('page_list_templates'), $total_records);
        //</editor-fold>

        //<editor-fold desc="LOAD THE TEMPLATE">
        $this->template->set('resultset', $result_set['templates']);
        $this->template->set('pagination', $pagination);
        $this->template->view($this->config->item('template_list_view'));
        //</editor-fold>
    }

    //<editor-fold desc="FUNCTION DESCRIPTION: SHOW THE TEMPLATE VIEW/EDIT PAGE">
    /**
     * Function: record
     * Description: Shows the template view/edit page
     * ##############################################################
     * Written: 10/10/2010
     * Author: Deep Arora
     * --------------------------------------------------------------
     * Update Log:
     * --------------------------------------------------------------
     * ##############################################################
     * @access public
     * @return void
     */
    //</editor-fold>
    function record($template_id = '', $offset = '')
    {
        //<editor-fold desc="CHECK USER PERMISSION">
        smp_check_permission($this->config->item('perm_view'));
        //</editor-fold>

        //<editor-fold desc="SET PAGE META">
        $page_button_set = array(
            'Add New'    =>  'templates/record',
            'View All'    =>  'templates'
        );
        smp_set_page_meta('config', 'templates', $page_button_set);
        //</editor-fold>

        //<editor-fold desc="FETCH FORM RULES & EXECUTE">
        $rules_config = smp_get_rules('templates');
        $this->form_validation->set_rules($rules_config);
        //</editor-fold>

        //<editor-fold desc="CREATE SEARCH FORM">
        $search_form_fields = array(
            array(
                'field'    =>  'template_title',
                'label'    =>  'Title',
                'type'     =>  'text',
                'class'    =>  '',
                'value'    =>  ''
            )
        );
        smp_create_form($search_form_fields, $this->config->item('form_template_search'), 'form_search');
        //</editor-fold>

        //<editor-fold desc="POPULATE THE FORM">
        if ($template_id): $where_additional = "template_id = " . $template_id; else: $where_additional = "template_id = 0"; endif;

        if ($this->input->post('action') && $this->form_validation->run()){
            smp_process_form($_POST, $this->config->item('tbl_templates'), 'template_id = ' . $template_id, 'config/templates');
        }
        $result_set = $this->Smp_model->get_records($this->config->item('tbl_templates'), $where_additional, $offset, $this->config->item('records_per_page'));

        if ($result_set):
            foreach ($result_set as $value){
                /*  Create edit form */
                $template_form_fields = array(
                   array(
                         'field'    =>  'template_id',
                         'label'    =>  'Template ID',
                         'type'     =>  'hidden',
                         'class'    =>  'small',
                         'value'    =>  $value->template_id
                      ),
                   array(
                         'field'    =>  'template_title',
                         'label'    =>  'Template Name',
                         'type'     =>  'text',
                         'class'    =>  'medium',
                         'value'    =>  $value->template_title
                      ),
                   array(
                         'field'    =>  'template_type',
                         'label'    =>  'Template Type',
                         'type'     =>  'dropdown',
                         'class'    =>  'medium',
                         'value'    =>  get_options($this->config->item('tbl_config'), 'key_value', 'key_value', 'key_name =\'TEMPLATE_TYPE\' AND flg_enabled = \'Y\' '),
                         'selected' =>  $value->template_type
                      ),
                    array(
                         'field'    =>  'template_code',
                         'label'    =>  'Template Code',
                         'type'     =>  'htmleditor',
                         'class'    =>  'expanded',
                         'value'    =>  $value->template_code,
                         'help'     =>  $this->lang->line('f_templates_template_code')
                      ),
                   array(
                         'field'    =>  'flg_enabled',
                         'label'    =>  'Enabled?',
                         'type'     =>  'dropdown',
                         'class'    =>  'small',
                         'value'    =>  get_options($this->config->item('tbl_config'), 'key_value', 'key_value', 'key_name =\'FLAG_YESNO\' AND flg_enabled = \'Y\' '),
                         'selected'    =>  $value->flg_enabled
                      )
                );

                smp_create_form($template_form_fields, $this->config->item('form_template_record') . '/' . $template_id, 'form_record', 'perm_delete');
            }
        else:
            /*  Create view form */
                $template_form_fields = array(
                   array(
                         'field'    =>  'template_title',
                         'label'    =>  'Template Name',
                         'type'     =>  'text',
                         'class'    =>  'medium',
                         'value'    =>  ''
                      ),
                   array(
                         'field'    =>  'template_type',
                         'label'    =>  'Template Type',
                         'type'     =>  'dropdown',
                         'class'    =>  'medium',
                         'value'    =>  get_options($this->config->item('tbl_config'), 'key_value', 'key_value', 'key_name =\'TEMPLATE_TYPE\' AND flg_enabled = \'Y\' '),
                         'selected' =>  ''
                      ),
                    array(
                         'field'    =>  'template_code',
                         'label'    =>  'Template Code',
                         'type'     =>  'htmleditor',
                         'class'    =>  'expanded',
                         'value'    =>  '',
                         'help'     =>  $this->lang->line('f_templates_template_code')
                      ),
                   array(
                         'field'    =>  'flg_enabled',
                         'label'    =>  'Enabled?',
                         'type'     =>  'dropdown',
                         'class'    =>  'small',
                         'value'    =>  get_options($this->config->item('tbl_config'), 'key_value', 'key_value', 'key_name =\'FLAG_YESNO\' AND flg_enabled = \'Y\' '),
                         'selected'    =>  ''
                      )
            );
            smp_create_form($template_form_fields, $this->config->item('form_template_record'), 'form_record', 'perm_add', 'plain');

        endif;
        //</editor-fold>

        //<editor-fold desc="LOAD THE TEMPLATE">
        $this->template->view($this->config->item('record_view'));
        //</editor-fold>
    }

     /**
     * Function: delete
     * Description: Deletes the Record
     * ##############################################################
     * Written: 05/01/2010
     * Author: Deep Arora
     * --------------------------------------------------------------
     * Update Log:
     * --------------------------------------------------------------
     * ##############################################################
     * @access public
     * @return void
     */
    function delete($template_id = '')
    {
        //<editor-fold desc="DELETE RECORD">
        if (smp_check_permission($this->config->item('perm_delete'))){
            $this->Shop_model->process_product('', 'Delete', 'product_id = ' . $product_id, 'shop/products');
        }
        //</editor-fold>
    }


}

/* End of file templates.php */
/* Location: ./app/controllers/config/templates.php */